PublicationBiasBenchmark_options: Options for the PublicationBiasBenchmark package

PublicationBiasBenchmark_optionsR Documentation

Options for the PublicationBiasBenchmark package

Description

A placeholder object and functions for the PublicationBiasBenchmark package.

Usage

PublicationBiasBenchmark.options(...)

PublicationBiasBenchmark.get_option(name)

Arguments

...

named option(s) to change - for a list of available options, see details below.

name

the name of the option to get the current value of - for a list of available options, see details below.

Details

"resources_directory"

Location where the benchmark data/results/measures are stored

"prompt_for_download"

Whether each file download should ask for explicit approval

Value

The current value of all available PublicationBiasBenchmark options (after applying any changes specified) is returned invisibly as a named list.


PublicationBiasBenchmark documentation built on March 16, 2026, 5:07 p.m.