View source: R/measures_pairwise.R
| compare_measures | R Documentation |
This is a high-level wrapper function that computes multiple pairwise comparison measures for a Data-Generating Mechanism (DGM) and saves the results to CSV files. It provides a clean and extensible interface for comparing method performance.
compare_measures(
dgm_name,
method,
method_setting,
measures = NULL,
verbose = TRUE,
estimate_col = "estimate",
true_effect_col = "mean_effect",
convergence_col = "convergence",
method_replacements = NULL,
n_repetitions = 1000,
overwrite = FALSE,
conditions = NULL
)
dgm_name |
Character string specifying the name of the DGM dataset to download. |
method |
Character vector of method names |
method_setting |
Character vector of method settings, must be same length as method |
measures |
Character vector of measures to compute. If NULL, computes all standard measures. |
verbose |
Print detailed progress of the calculation. |
estimate_col |
Character string specifying the column name containing parameter estimates. Default is "estimate" |
true_effect_col |
Character string specifying the column name in conditions data frame containing true effect sizes. Default is "mean_effect" |
convergence_col |
Character string specifying the column name containing convergence indicators. Default is "convergence" |
method_replacements |
Named list of replacement method specifications. Each element should be named with the "method-method_setting" combination (e.g., "RMA-default") and contain a named list with:
If multiple elements are specified within the vectors, these replacements are applied consecutively
in case the previous replacements also failed to converge.
Defaults to |
n_repetitions |
Number of repetitions in each condition. Necessary method replacement. Defaults to |
overwrite |
Logical indicating whether to overwrite existing files.
Defaults to |
conditions |
Data frame of conditions from dgm_conditions() |
Invisible list of computed comparison data frames
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.