| dgm.no_bias | R Documentation |
An example data-generating mechanism to simulate effect sizes without publication bias.
## S3 method for class 'no_bias'
dgm(dgm_name, settings)
dgm_name |
DGM name (automatically passed) |
settings |
List containing
|
Sample sizes of individual effect size estimates are generated from a negative binomial distribution based on empirical sample size distribution presented in Appendix B of \insertCitemaier2023robust;textualPublicationBiasBenchmark
Data frame with
effect size
standard error
sample size
effect size type
František Bartoš f.bartos96@gmail.com
dgm(), validate_dgm_setting()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.