| download_dgm | R Documentation |
This function downloads datasets/results/measures of a specified Data-Generating Mechanism (DGM)
from the OSF repository (https://osf.io/exf3m/). The datasets/results/measures are saved
to the location specified via PublicationBiasBenchmark.options(resources_directory = "/path/").
To set the location permanently, specify the PublicationBiasBenchmark_RESOURCES environment
variable. The data are stored in dgm_name/datasets, dgm_name/results, dgm_name/measures subfolders.
download_dgm_datasets(
dgm_name,
overwrite = FALSE,
progress = TRUE,
max_try = 10
)
download_dgm_results(
dgm_name,
overwrite = FALSE,
progress = TRUE,
max_try = 10
)
download_dgm_measures(
dgm_name,
overwrite = FALSE,
progress = TRUE,
max_try = 10
)
dgm_name |
Character string specifying the name of the DGM dataset to download. |
overwrite |
Logical indicating whether to overwrite existing files.
Defaults to |
progress |
Logical indicating whether to show progress downloading files.
Defaults to |
max_try |
Integet specifying how many times should the function attempt reconnecting to OSF upon failure. |
TRUE if the download was successful, otherwise an error is raised.
## Not run:
download_dgm_datasets("no_bias")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.