| method.SM | R Documentation |
Implements selection models for publication bias correction in meta-analysis. The method first fits a random effects meta-analysis model, then applies selection modeling to adjust for publication bias using the metafor package. Selection models account for the probability that studies are published based on their p-values or effect sizes. See \insertCitevevea1995general;textualPublicationBiasBenchmark for details.
## S3 method for class 'SM'
method(method_name, data, settings)
method_name |
Method name (automatically passed) |
data |
Data frame with yi (effect sizes) and sei (standard errors) |
settings |
List of method settings (see Details) |
The following settings are implemented
"default" or "3PSM"3-parameter step function selection model with
Maximum Likelihood estimator (method = "ML") and one step
at one-sided p = 0.025 (i.e., selection for significance))
"4PSM"4-parameter step function selection model with
Maximum Likelihood estimator (method = "ML") and two steps
at one-sided p = 0.025 and p = 0.50 (i.e., selection for significance
and direction of the effect)
Data frame with SM results
František Bartoš f.bartos96@gmail.com
# Generate some example data
data <- data.frame(
yi = c(0.2, 0.3, 0.1, 0.4, 0.25),
sei = c(0.1, 0.15, 0.08, 0.12, 0.09)
)
# Apply SM method
result <- run_method("SM", data, "3PSM")
print(result)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.