| method.WILS | R Documentation |
Implements the weighted and iterated least squares (WILS) method for publication bias correction in meta-analysis. The method is based on the idea of using excess statistical significance (ESS) to identify how many underpowered studies should be removed to reduce publication selection bias. See \insertCitestanley2024harnessing;textualPublicationBiasBenchmark for details.
## S3 method for class 'WILS'
method(method_name, data, settings = NULL)
method_name |
Method name (automatically passed) |
data |
Data frame with yi (effect sizes) and sei (standard errors) |
settings |
List of method settings (see Details) |
The WILS method has two implementation versions based on Stanley & Doucouliagos (2024). The following settings are implemented
"default"The simulation version (default) uses residuals from the t ~ Precision regression for the first iteration, then switches to individual excess statistical significance (ESS) for subsequent iterations.
"example"The example version consistently uses residuals from the t ~ Precision regression to identify studies to remove across all iterations.
Data frame with WILS results
František Bartoš f.bartos96@gmail.com
# Generate some example data
data <- data.frame(
yi = c(0.2, 0.3, 0.1, 0.4, 0.25),
sei = c(0.1, 0.15, 0.08, 0.12, 0.09)
)
# Apply WILS method
result <- run_method("WILS", data)
print(result)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.