method.WLS: WLS (Weighted Least Squares) Method

View source: R/method-WLS.R

method.WLSR Documentation

WLS (Weighted Least Squares) Method

Description

Implements the Weighted Least Squares method for meta-analysis. WLS fits a weighted regression model with effect sizes as the outcome and weights based on the inverse of the squared standard errors. The intercept represents the weighted average effect size estimate.

Usage

## S3 method for class 'WLS'
method(method_name, data, settings = NULL)

Arguments

method_name

Method name (automatically passed)

data

Data frame with yi (effect sizes) and sei (standard errors)

settings

List of method settings (no settings version are implemented)

Value

Data frame with WLS results

Author(s)

František Bartoš f.bartos96@gmail.com

References

\insertAllCited

Examples

# Generate some example data
data <- data.frame(
  yi = c(0.2, 0.3, 0.1, 0.4, 0.25),
  sei = c(0.1, 0.15, 0.08, 0.12, 0.09)
)

# Apply WLS method
result <- run_method("WLS", data)
print(result)


PublicationBiasBenchmark documentation built on March 16, 2026, 5:07 p.m.