method.default: Default method handler

View source: R/method.R

method.defaultR Documentation

Default method handler

Description

Default method handler

Usage

## Default S3 method:
method(method_name, data, settings = list())

Arguments

method_name

Character string specifying the method type

data

Data frame containing yi (effect sizes) and sei (standard errors)

settings

Either a character identifying a method version or list containing method-specific settings. An emty input will result in running the default (first implemented) version of the method.

Value

Throws an error indicating the method type is unknown. This default method is only called when no specific method implementation is found for the given method_name.


PublicationBiasBenchmark documentation built on March 16, 2026, 5:07 p.m.