method_settings: Return Pre-specified Method Settings

View source: R/method.R

method_settingsR Documentation

Return Pre-specified Method Settings

Description

This function returns the list of pre-specified settings for a given Method

Usage

method_settings(method_name)

get_method_setting(method_name, version_id)

Arguments

method_name

Character string specifying the method type

version_id

which method version should be used.

Value

A list containing the pre-specified settings. For most methods, the list contains extension of the function call, however, a more elaborate list of settings that is dispatched within the method call is possible.

Examples

method_settings("RMA")
get_method_setting("RMA", version_id = "default")


PublicationBiasBenchmark documentation built on March 16, 2026, 5:07 p.m.