| retrieve_dgm_dataset | R Documentation |
This function returns a pre-simulated dataset of a given repetition and condition from a dgm. The pre-simulated datasets must be already stored locally. See download_dgm function for more guidance.
retrieve_dgm_dataset(dgm_name, condition_id, repetition_id = NULL)
dgm_name |
Character string specifying the DGM type |
condition_id |
which conditions should settings be returned for. |
repetition_id |
Which repetition should be returned. The complete
condition can be returned by setting to either |
A data.frame
## Not run:
# get condition 1, repetition 1
retrieve_dgm_dataset("no_bias", condition_id = 1, repetition_id = 1)
# get condition 1, all repetitions
retrieve_dgm_dataset("no_bias", condition_id = 1)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.