| retrieve_dgm_measures | R Documentation |
This function returns pre-computed performance measures for a specified
Data-Generating Mechanism (DGM). The pre-computed measures must be already stored
locally. See download_dgm_measures() function for more guidance.
retrieve_dgm_measures(
dgm_name,
measure = NULL,
method = NULL,
method_setting = NULL,
condition_id = NULL,
replacement = FALSE
)
dgm_name |
Character string specifying the DGM type |
measure |
Which performance measure should be returned (e.g., "bias", "mse", "coverage").
All measures can be returned by setting to |
method |
Which method(s) should be returned. The complete results are returned by setting to |
method_setting |
Which method setting(s) should be returned. The complete results are returned by setting to |
condition_id |
which conditions should settings be returned for. |
replacement |
Whether performance measures computed using replacement should be returned. Defaults to |
A data.frame
## Not run:
# get bias measures for all methods and conditions
retrieve_dgm_measures("no_bias", measure = "bias")
# get all measures for RMA method
retrieve_dgm_measures("no_bias", method = "RMA")
# get MSE measures for PET method in condition 1
retrieve_dgm_measures("no_bias", measure = "mse", method = "PET", condition_id = 1)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.