| retrieve_dgm_results | R Documentation |
This function returns a pre-computed results of a given method at a specific
repetition and condition from a dgm. The pre-computed results must be already stored
locally. See download_dgm_results() function for more guidance.
retrieve_dgm_results(
dgm_name,
method = NULL,
method_setting = NULL,
condition_id = NULL,
repetition_id = NULL
)
dgm_name |
Character string specifying the DGM type |
method |
Which method(s) should be returned. The complete results are returned by setting to |
method_setting |
Which method setting(s) should be returned. The complete results are returned by setting to |
condition_id |
which conditions should settings be returned for. |
repetition_id |
Which repetition should be returned. The complete
condition can be returned by setting to either |
A data.frame
## Not run:
# get condition 1, repetition 1 for default method setting
retrieve_dgm_results("no_bias", condition_id = 1, repetition_id = 1)
# get condition 1, all repetitions for default method setting
retrieve_dgm_results("no_bias", condition_id = 1)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.