| PublicationBiasBenchmark_options | R Documentation |
A placeholder object and functions for the PublicationBiasBenchmark package.
PublicationBiasBenchmark.options(...)
PublicationBiasBenchmark.get_option(name)
... |
named option(s) to change - for a list of available options, see details below. |
name |
the name of the option to get the current value of - for a list of available options, see details below. |
"resources_directory"Location where the benchmark data/results/measures are stored
"prompt_for_download"Whether each file download should ask for explicit approval
The current value of all available PublicationBiasBenchmark options (after applying any changes specified) is returned invisibly as a named list.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.