This is a high-level wrapper function that computes multiple pairwise comparison measures for a Data-Generating Mechanism (DGM) and saves the results to CSV files. It provides a clean and extensible interface for comparing method performance.
compare_measures(
dgm_name,
method,
method_setting,
measures = NULL,
verbose = TRUE,
estimate_col = "estimate",
true_effect_col = "mean_effect",
convergence_col = "convergence",
method_replacements = NULL,
n_repetitions = 1000,
overwrite = FALSE,
conditions = NULL
)Invisible list of computed comparison data frames
Character string specifying the name of the DGM dataset to download.
Character vector of method names
Character vector of method settings, must be same length as method
Character vector of measures to compute. If NULL, computes all standard measures.
Print detailed progress of the calculation.
Character string specifying the column name containing parameter estimates. Default is "estimate"
Character string specifying the column name in conditions data frame containing true effect sizes. Default is "mean_effect"
Character string specifying the column name containing convergence indicators. Default is "convergence"
Named list of replacement method specifications. Each element should be named with the "method-method_setting" combination (e.g., "RMA-default") and contain a named list with:
method: Character vector of replacement method names
method_setting: Character vector of replacement method settings (same length as methods)
power_test_type: Optional character vector of power test types for each replacement method (same length as methods). If not specified, uses the main power_test_type parameter
If multiple elements are specified within the vectors, these replacements are applied consecutively
in case the previous replacements also failed to converge.
Defaults to NULL, i.e., omitting repetitions without converged results on method-by-method basis.
Number of repetitions in each condition. Necessary method replacement. Defaults to 1000.
Logical indicating whether to overwrite existing files.
Defaults to FALSE, which means only missing files will be downloaded.
Data frame of conditions from dgm_conditions()