An example data-generating mechanism to simulate effect sizes without publication bias.
# S3 method for no_bias
dgm(dgm_name, settings)Data frame with
effect size
standard error
sample size
effect size type
DGM name (automatically passed)
List containing
Mean effect
Effect heterogeneity
Number of effect size estimates
Sample sizes of individual effect size estimates are generated from a negative binomial distribution based on empirical sample size distribution presented in Appendix B of maier2023robust;textualPublicationBiasBenchmark
dgm(), validate_dgm_setting()