| dgm_conditions | R Documentation |
This function returns the list of pre-specified settings for a given Data Generating Mechanism (DGM).
dgm_conditions(dgm_name)
get_dgm_condition(dgm_name, condition_id)
dgm_name |
Character string specifying the DGM type |
condition_id |
which conditions should settings be returned for. |
A data frame containing the pre-specified settings including a
condition_id column which maps settings id to the corresponding settings.
head(dgm_conditions("Carter2019"))
get_dgm_condition("Carter2019", condition_id = 1)
head(dgm_conditions("Alinaghi2018"))
head(dgm_conditions("Stanley2017"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.