powered by
This function returns the list of pre-specified settings for a given Data Generating Mechanism (DGM).
dgm_conditions(dgm_name)get_dgm_condition(dgm_name, condition_id)
get_dgm_condition(dgm_name, condition_id)
A data frame containing the pre-specified settings including a condition_id column which maps settings id to the corresponding settings.
condition_id
Character string specifying the DGM type
which conditions should settings be returned for.
head(dgm_conditions("Carter2019")) get_dgm_condition("Carter2019", condition_id = 1) head(dgm_conditions("Alinaghi2018")) head(dgm_conditions("Stanley2017"))
Run the code above in your browser using DataLab