Learn R Programming

PublicationBiasBenchmark (version 0.1.3)

measure: Get performance measure function

Description

Returns the function for computing a specific performance measure. Can also be used to list available measures.

Usage

measure(measure, ...)

Value

A function that computes the requested measure, or a character vector of measure names.

Arguments

measure

Character string specifying the measure name. If missing, returns a vector of all available measures.

...

Additional arguments passed to methods.