| measure_mcse | R Documentation |
Returns the function for computing the Monte Carlo Standard Error (MCSE) of a specific performance measure. Can also be used to list available measures with MCSE functions.
measure_mcse(measure, ...)
measure |
Character string specifying the measure name. If missing, returns a vector of all available measures. |
... |
Additional arguments passed to methods. |
A function that computes the MCSE of the requested measure, or a character vector of measure names.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.