Learn R Programming

PublicationBiasBenchmark (version 0.1.3)

measure_mcse: Get performance measure MCSE function

Description

Returns the function for computing the Monte Carlo Standard Error (MCSE) of a specific performance measure. Can also be used to list available measures with MCSE functions.

Usage

measure_mcse(measure, ...)

Value

A function that computes the MCSE of the requested measure, or a character vector of measure names.

Arguments

measure

Character string specifying the measure name. If missing, returns a vector of all available measures.

...

Additional arguments passed to methods.