| method.AK | R Documentation |
Implements the Andrews & Kasy (AK) method for publication bias correction in meta-analysis. The AK method categorizes estimated effects into groups with different probabilities of being published. AK1 uses symmetric selection grouping estimates into significant (|t| >= 1.96) and insignificant (|t| < 1.96) estimates. AK2 uses asymmetric selection with four groups based on both significance and sign: highly significant positive/negative effects and marginally significant positive/negative effects, each with different publication probabilities. See \insertCiteandrews2019identification;textualPublicationBiasBenchmark for details.
## S3 method for class 'AK'
method(method_name, data, settings)
method_name |
Method name (automatically passed) |
data |
Data frame with yi (effect sizes), sei (standard errors), and study_id (for clustering wherever available) |
settings |
List of method settings (see Details) |
The following settings are implemented
"default"Uses AK1 estimator (symmetric selection)
"AK1"Symmetric selection model grouping estimates into significant (|t| >= 1.96) and insignificant (|t| < 1.96) categories with relative publication probabilities of 1 and p1 respectively.
"AK2"Asymmetric selection model with four groups based on t-statistics: (a) t >= 1.96, (b) t < -1.96, (c) -1.96 <= t < 0, and (d) 0 <= t < 1.96, with relative publication probabilities of 1, p1, p2, and p3 respectively.
Data frame with AK results
František Bartoš f.bartos96@gmail.com
# Generate some example data
data <- data.frame(
yi = c(0.2, 0.3, 0.1, 0.4, 0.25),
sei = c(0.1, 0.15, 0.08, 0.12, 0.09)
)
# Apply AK method
result <- run_method("AK", data, "default")
print(result)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.