| method.RoBMA | R Documentation |
Implements the robust Bayesian meta-analysis (RoBMA) method that uses
Bayesian model-averaging to combine results across several complementary
publication bias adjustment methods. See
\insertCitemaier2023robust;textualPublicationBiasBenchmark and
\insertCitebartos2023robust;textualPublicationBiasBenchmark for
details. If "study_id" column is included in the data input,
the method uses multilevel parameterization as described in
\insertCitebartos2025robust;textualPublicationBiasBenchmark.
Note that the prior settings is dispatched based on "es_type" column attached
to the dataset. The resulting estimates are then summarized on the same scale
as was the dataset input (for "r", heterogeneity is summarized on Fisher's z).
Important: This method requires JAGS (Just Another Gibbs Sampler) to be installed on your system. Please download and install JAGS from https://mcmc-jags.sourceforge.io/ before using this method.
## S3 method for class 'RoBMA'
method(method_name, data, settings)
method_name |
Method name (automatically passed) |
data |
Data frame with yi (effect sizes), sei (standard errors), es_type
(either |
settings |
List of method settings (see Details.) |
The following settings are implemented
"default"RoBMA-PSMA with publication bias adjustment as described in
\insertCitebartos2023robust;textualPublicationBiasBenchmark.
(the MCMC settings was reduced to speed-up the simulations) with the
three-level specification whenever "study_ids" are supplied with the data
"PSMA"RoBMA-PSMA with publication bias adjustment as described in
\insertCitebartos2023robust;textualPublicationBiasBenchmark.
(the MCMC settings was reduced to speed-up the simulations) with the
three-level specification whenever "study_ids" are supplied with the data
Data frame with RoBMA results
František Bartoš f.bartos96@gmail.com
# Generate some example data
data <- data.frame(
yi = c(0.2, 0.3, 0.1, 0.4, 0.25),
sei = c(0.1, 0.15, 0.08, 0.12, 0.09),
es_type = "SMD"
)
# Apply RoBMA method
result <- run_method("RoBMA", data)
print(result)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.