View source: R/method-WAAPWLS.R
| method.WAAPWLS | R Documentation |
Implements the WAAP-WLS method for meta-analysis, which combines WLS and WAAP approaches. First fits a WLS model to all studies, then identifies high-powered studies based on the criterion that the WLS estimate divided by 2.8 is greater than or equal to the standard error. If at least 2 high-powered studies are found, uses WAAP (weighted average of adequate power studies only), otherwise uses the original WLS estimate. See \insertCitestanley2017finding;textualPublicationBiasBenchmark for details.
## S3 method for class 'WAAPWLS'
method(method_name, data, settings = NULL)
method_name |
Method name (automatically passed) |
data |
Data frame with yi (effect sizes) and sei (standard errors) |
settings |
List of method settings (no settings version are implemented) |
Data frame with WAAPWLS results
František Bartoš f.bartos96@gmail.com
# Generate some example data
data <- data.frame(
yi = c(0.2, 0.3, 0.1, 0.4, 0.25),
sei = c(0.1, 0.15, 0.08, 0.12, 0.09)
)
# Apply WAAPWLS method
result <- run_method("WAAPWLS", data)
print(result)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.