| method.default | R Documentation |
Default method handler
## Default S3 method:
method(method_name, data, settings = list())
method_name |
Character string specifying the method type |
data |
Data frame containing yi (effect sizes) and sei (standard errors) |
settings |
Either a character identifying a method version or list containing method-specific settings. An emty input will result in running the default (first implemented) version of the method. |
Throws an error indicating the method type is unknown. This default
method is only called when no specific method implementation is found for the
given method_name.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.