View source: R/method-pcurve.R
| method.pcurve | R Documentation |
Implements the p-Curve method which analyzes the distribution of p-values from significant studies to assess whether the significant findings reflect true effects or QRP/publication bias. The method also provides tests for the evidential value, lack of evidential value, and p-hacking. See \insertCitesimonsohn2014pcurve;textualPublicationBiasBenchmark for details.
The current implementation does not provide a test against the null hypothsis of no effect and does not produce confidence intervals of the estimate.
## S3 method for class 'pcurve'
method(method_name, data, settings)
method_name |
Method name (automatically passed) |
data |
Data frame with yi (effect sizes), sei (standard errors), and ni (sample sizes wherever available, otherwise set to Inf) |
settings |
List of method settings (see Details) |
The following settings are implemented
"default"no options
Data frame with P-Curve results
František Bartoš f.bartos96@gmail.com
# Generate some example data
data <- data.frame(
yi = c(0.2, 0.3, 0.1, 0.4, 0.25),
sei = c(0.1, 0.15, 0.08, 0.12, 0.09)
)
# Apply pcurve method
result <- run_method("pcurve", data)
print(result)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.