View source: R/method-puniform.R
| method.puniform | R Documentation |
Implements the p-uniform method for publication bias detection and correction. P-uniform uses the distribution of p-values from significant studies to test for publication bias and estimate the effect size corrected for publication bias. The method assumes that p-values follow a uniform distribution under the null hypothesis of no effect, and uses this to detect and correct for bias. See \insertCitevanassen2015meta;textualPublicationBiasBenchmark and \insertCitevanaert2025puniform;textualPublicationBiasBenchmark for details.
## S3 method for class 'puniform'
method(method_name, data, settings)
method_name |
Method name (automatically passed) |
data |
Data frame with yi (effect sizes) and sei (standard errors) |
settings |
List of method settings (see Details) |
The following settings are implemented
"default"Default p-uniform analysis settings.
"star"P-uniform star version of the method.
Data frame with P-Uniform results
František Bartoš f.bartos96@gmail.com
# Generate some example data
data <- data.frame(
yi = c(0.2, 0.3, 0.1, 0.4, 0.25),
sei = c(0.1, 0.15, 0.08, 0.12, 0.09)
)
# Apply puniform method
result <- run_method("puniform", data)
print(result)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.