| method_settings | R Documentation |
This function returns the list of pre-specified settings for a given Method
method_settings(method_name)
get_method_setting(method_name, version_id)
method_name |
Character string specifying the method type |
version_id |
which method version should be used. |
A list containing the pre-specified settings. For most methods, the list contains extension of the function call, however, a more elaborate list of settings that is dispatched within the method call is possible.
method_settings("RMA")
get_method_setting("RMA", version_id = "default")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.